@@ -4,9 +4,10 @@
 import sys
 import os
 import threading
-
+import time
 import gobject
 import gtk
+import shutil
 gtk.gdk.threads_init()
 import gtk.glade
 import datetime
@@ -18,16 +19,30 @@ try:
 except ImportError:
   hildon = None
 
+def ask_dialogue(win,message):
+  dialog = gtk.MessageDialog(win,
+                  gtk.DIALOG_MODAL,
+                  gtk.MESSAGE_QUESTION,
+                  gtk.BUTTONS_YES_NO,
+                  message)
+  rc = dialog.run ()
+  dialog.destroy ()
+
+  if rc == gtk.RESPONSE_YES:
+    return True
+  else:
+    return False
+    
 class mNotes(object):
 
   __pretty_app_name__ = "mNotes"
   __app_name__ = "mNotes"
-  __version__ = "0.2.4"
+  __version__ = "0.2.5"
   __context__ = "net.khertan.mnotes"
 
   _glade_files = [
-    '/usr/lib/mnotes/ui/mnotes.glade',
-    #'ui/mnotes.glade',
+    #'/usr/lib/mnotes/ui/mnotes.glade',
+    'ui/mnotes.glade',
   ]
 
   def __init__(self,app,context):
@@ -60,8 +75,18 @@ class mNotes(object):
       self._window.set_border_width(0)
       self._widgetTree.get_widget("vbox1").reparent(self._window)
       self._app.add_window(self._window)
+
       hildon.hildon_helper_set_thumb_scrollbar(self._widgetTree.get_widget('scrolledwindow1'),True)
+#      import mokoui
+#      mokoscroll = mokoui.FingerScroll()
+#      for child in self._widgetTree.get_widget('scrolledwindow2').get_children():
+#        child.reparent(mokoscroll)
+#      parent = self._widgetTree.get_widget('scrolledwindow2').get_parent()
+#      self._widgetTree.get_widget('scrolledwindow2').destroy()
+#      parent.add(mokoscroll) 
+#      mokoscroll.show()
       hildon.hildon_helper_set_thumb_scrollbar(self._widgetTree.get_widget('scrolledwindow2'),True)
+
       self._window.connect("key-press-event", self._on_key_press)
       self._window.connect("window-state-event", self._on_window_state_change)
     else:
@@ -72,30 +97,41 @@ class mNotes(object):
     else:
       self._window.set_title("%s" % self.__pretty_app_name__)
 
+    self._imagewin = self._widgetTree.get_widget("ImageView")
+    self._textwin = self._widgetTree.get_widget("TextView")
+    self._drawwin = self._widgetTree.get_widget("DrawingView")
+    
+    self._bTitlePict = self._widgetTree.get_widget("bTitlePict")
+    self._bTitleDraw= self._widgetTree.get_widget("bTitleDraw")
+
     self._draw_pencil = self._widgetTree.get_widget("bPencil")
     self._draw_clear = self._widgetTree.get_widget("bClearDraw")
-    
+
     callbackMapping = {
       # EventsList Signal
       "on_Del_clicked": self._delete_note,
-      "on_Add_clicked": self._add_note,
+      "on_AddDraw_clicked": self._add_draw_note,
+      "on_AddPict_clicked": self._add_pict_note,
+      "on_AddText_clicked": self._add_text_note,
       "on_Search_clicked": self._search_note,
       "on_bPick_clicked": self.button_cam,
       "on_bPencil_clicked": self.toggle_draw_button_pencil,
       "on_bClearDraw_clicked": self.toggle_draw_button_clear,
-      "on_notebook_switch_page": self._page_changed,
+      "on_AddImage_clicked":self._add_image,
+#      "on_notebook_switch_page": self._page_changed,
 
 #      "on_Liste_row_activated": self._row_selected,
     }
     self._widgetTree.signal_autoconnect(callbackMapping)
 
     self._load_hpane_position()
-
+    self._current_selection_iter = None
+    
     if self._window:
       self._children_color_bg(self._window)
       self._window.connect("delete-event", self._win_closebox)
-      self._window.show_all()      
-    
+      self._window.show()      
+
     self._drawview = self._widgetTree.get_widget("DrawView")
     self._drawview.connect("configure_event", self.draw_configure_event)
     self._drawview.set_events(gtk.gdk.EXPOSURE_MASK |
@@ -123,8 +159,40 @@ class mNotes(object):
 #    if page_num == 1:
 #      self._load_current_note_draw()
 
+  def _switch_view(self,view):
+    if view == 0:
+      self._imagewin.hide()
+      self._textwin.show()
+      self._drawwin.hide()
+    elif view == 1:
+      self._imagewin.hide()
+      self._textwin.hide()
+      self._drawwin.show()
+      self._window.set_focus(self._bTitleDraw)
+    elif view == 2:
+      self._imagewin.show()
+      self._window.set_focus(self._bTitlePict)
+      self._widgetTree.get_widget("Photo").hide()
+      self._textwin.hide()
+      self._drawwin.hide()
+
+  def _load_current_note_pict(self):
+    if self._current_note.have_photo == False:
+      self._photoview.set_from_stock(gtk.STOCK_MISSING_IMAGE,gtk.ICON_SIZE_DND)
+    else:
+      pixbuf = gtk.gdk.pixbuf_new_from_file_at_scale(self._current_note.get_photo_path(),320,240,gtk.gdk.INTERP_BILINEAR)
+      if pixbuf == None:
+        pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 320, 240)
+      try:
+#        w,h = (pixbuf.get_width(),pixbuf.get_height())
+#        scaled_buf = pixbuf.scale_simple(320,h/(w/320),gtk.gdk.INTERP_BILINEAR)
+        self._photoview.set_from_pixbuf(pixbuf)
+      except StandardError,e:
+        print e
+        pass
+
   def _load_current_note_draw(self):
-    if self._current_note.draw == True:
+    if self._current_note.have_draw == True:
 #      self._drawview.show()
       pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_draw_path())
       if pixbuf == None:
@@ -154,24 +222,31 @@ class mNotes(object):
         print e
         self._current_note.draw_loaded = False
         pass
-      
+
   def _save_current_note(self):
     if self._current_note != None:
-      buffer = self._editor.get_buffer()
-      start, end = buffer.get_bounds ()      
-      self._current_note.description = buffer.get_text(start,end)
+    
+      if self._current_note.type == 0:
+        buffer = self._editor.get_buffer()
+        start, end = buffer.get_bounds ()      
+        self._current_note.description = buffer.get_text(start,end)
+      elif self._current_note.type == 1:
+        self._current_note.description = self._bTitleDraw.get_text()
+      elif self._current_note.type == 2:
+        self._current_note.description = self._bTitlePict.get_text()
       self._current_note.save_to_db()
 
-      if (self._drawview.window != None) and (self._current_note.draw_loaded == True):
-        width, height =600,400 #self._drawview.window.get_size ()
-        pixbuf = gtk.gdk.Pixbuf (gtk.gdk.COLORSPACE_RGB, 0, 8, width, height)
-        pixbuf.get_from_drawable(self.pixmap, self.pixmap.get_colormap (),0, 0, 0, 0, width, height)
-        pixbuf.save (self._current_note.get_draw_path(), "jpeg")
-        del pixbuf 
-        
-      if (self._current_selection_iter):
-        uuid = self._notesList.set_value(self._current_selection_iter, 1,self._current_note.title)
-
+      if self._current_note.type == 1:
+        if (self._drawview.window != None) and (self._current_note.draw_loaded == True):
+          width, height =600,400 #self._drawview.window.get_size ()
+          pixbuf = gtk.gdk.Pixbuf (gtk.gdk.COLORSPACE_RGB, 0, 8, width, height)
+          pixbuf.get_from_drawable(self.pixmap, self.pixmap.get_colormap (),0, 0, 0, 0, width, height)
+          pixbuf.save (self._current_note.get_draw_path(), "jpeg")
+          del pixbuf 
+      elif self._current_note== 2:  
+        if (self._current_selection_iter):
+          uuid = self._notesList.set_value(self._current_selection_iter, 1,self._current_note.title)
+  
       self.refresh()
       #self._load_noteslist_bg()
 
@@ -182,19 +257,25 @@ class mNotes(object):
     if (selection_iter):
       uuid = self._notesList.get_value(selection_iter, 0)
       self._save_current_note()
+      if self._current_selection_iter != None:
+        self._notesList.set_value(self._current_selection_iter, 1,self._current_note.title)
       self._current_selection_iter = selection_iter
       self._current_note = mnotes_framework.Note(uuid)
+      self._current_note.draw_loaded = False
       self._editor.get_buffer().set_text(self._current_note.description)
       #Load photo
-      if (self._current_note.photo == True) :
-        self._photoview.set_from_file(self._current_note.get_photo_path())
-      else:
-        self._photoview.set_from_stock(gtk.STOCK_MISSING_IMAGE,gtk.STATE_NORMAL)
+      if (self._current_note.type == 2) :
+        self._bTitlePict.set_text(self._current_note.title)
+        self._load_current_note_pict()
+        #self._photoview.set_from_file(self._current_note.get_photo_path())
+        self._switch_view(self._current_note.type)
       #load draw here only when the drawingarea have window so when selected page on the notebook
-      if self._widgetTree.get_widget("notebook1").get_current_page()==1:
+      elif (self._current_note.type == 1) :
+        self._bTitleDraw.set_text(self._current_note.title)
         self._load_current_note_draw()
+        self._switch_view(self._current_note.type)
       else:
-        self._current_note.draw_loaded = False
+        self._switch_view(self._current_note.type)
     return
 
   def _search_note(self,widget):
@@ -202,17 +283,18 @@ class mNotes(object):
     self._load_noteslist_bg()
 
   def _delete_note(self,widget):
-    selection = self.notesListTree.get_selection()
-    model, selection_iter = selection.get_selected()
-    if (selection_iter):
-      uuid = self._notesList.get_value(selection_iter, 0)
-      note = mnotes_framework.Note(uuid)
-      self._notesList.remove(selection_iter)
-      note.delete_from_db()
+    if ask_dialogue(self._window,'Do you really want to delete this note ?')==True:
       selection = self.notesListTree.get_selection()
-      self.notesListTree.set_cursor(0)
-      selection.select_path(0)
-      self.refresh()  
+      model, selection_iter = selection.get_selected()
+      if (selection_iter):
+        uuid = self._notesList.get_value(selection_iter, 0)
+        note = mnotes_framework.Note(uuid)
+        self._notesList.remove(selection_iter)
+        note.delete_from_db()
+        selection = self.notesListTree.get_selection()
+        self.notesListTree.set_cursor(0)
+        selection.select_path(0)
+        self.refresh()  
 
   def refresh(self):
     self._pijama_color()
@@ -230,9 +312,49 @@ class mNotes(object):
       iter = self._notesList.iter_next(iter)
     self.notesListTree.queue_draw()
 
-  def _add_note(self,widget):
+  def _add_image(self,widget, *args):
+    dialog = hildon.FileChooserDialog(self._window, "open")
+    if(dialog.run()==gtk.RESPONSE_OK) and (dialog.get_filename()!=None):
+      try:
+        filename=dialog.get_filename()
+        dialog.destroy()
+#        self.open_file(filename)
+        shutil.copyfile(filename, self._current_note.get_photo_path())
+        self._load_current_note_pict()
+#        pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_photo_path())
+#        w,h = (pixbuf.get_width(),pixbuf.get_height())
+#        scaled_buf = pixbuf.scale_simple(320,h/(w/320),gtk.gdk.INTERP_BILINEAR)
+#        self._photoview.set_from_pixbuf(scaled_buf)
+#        self._photoview.set_from_file(filename)
+      except StandardError,e:
+        print e
+        dialog.destroy()
+        self.alert_dialog(e.__str__())
+      else:
+        dialog.destroy()
+
+  def alert_dialog(self,message):
+    dialog = gtk.MessageDialog(self,
+                    gtk.DIALOG_MODAL,
+                    gtk.MESSAGE_ERROR,
+                    gtk.BUTTONS_OK,
+                    message)
+    rc = dialog.run ()
+    dialog.destroy ()
+
+  def _add_text_note(self,widget):
+    self._add_note(0)
+
+  def _add_draw_note(self,widget):
+    self._add_note(1)
+
+  def _add_pict_note(self,widget):
+    self._add_note(2)
+
+  def _add_note(self,note_type):
     self._save_current_note()
     note = mnotes_framework.Note('')
+    note.type = note_type
     self._notesList_append(self._notesList,note.uuid,note.title,note.get_fg_color(),note.get_bg_color(),note.get_style())
     note.save_to_db()
     selection = self.notesListTree.get_selection()
@@ -354,13 +476,14 @@ class mNotes(object):
       self._draw_mode=1
 
   def draw_expose_event(self,widget, event):
-  
-    if self._current_note.draw_loaded == False:
-      self._load_current_note_draw()
-    x, y, width, height = event.area
-    gc = widget.get_style().fg_gc[gtk.STATE_NORMAL]
-    widget.window.draw_drawable(gc, self.pixmap, x, y, x, y, width, height)
-    return False
+    if self._current_note != None:
+      if self._current_note.type == 1:
+        if self._current_note.draw_loaded == False:
+          self._load_current_note_draw()
+        x, y, width, height = event.area
+        gc = widget.get_style().fg_gc[gtk.STATE_NORMAL]
+        widget.window.draw_drawable(gc, self.pixmap, x, y, x, y, width, height)
+      return False
 
   def draw_clean(self,widget, x, y):
     x, y = int(x), int(y)
@@ -465,7 +588,12 @@ class mNotes(object):
     from easy import camera
     camera.click(self._current_note.get_photo_path())
     self._current_note.test_have_photo()
-    self._photoview.set_from_file(self._current_note.get_photo_path())
+    self._load_current_note_pict()
+#    pixbuf = gtk.gdk.pixbuf_new_from_file(self._current_note.get_photo_path())       
+#    w,h = (pixbuf.get_width(),pixbuf.get_height())
+#    scaled_buf = pixbuf.scale_simple(320,h/(w/320),gtk.gdk.INTERP_BILINEAR)
+#    self._photoview.set_from_pixbuf(scaled_buf)
+#    #self._photoview.set_from_file(self._current_note.get_photo_path())
     gtk.gdk.threads_leave()
 
   def button_cam(self,widget):
@@ -496,6 +624,11 @@ class mNotes(object):
 #    print type(self._widgetTree.get_widget("drawingarea1").window.xid)
 #    self._widgetTree.get_widget("drawingarea1").show()
 #    self._widgetTree.get_widget("xwindow").set_size_request(64,48)
+    
+#    while (self._widgetTree.get_widget("Photo").window == None):
+#      time.sleep(1)
+    gtk.gdk.threads_leave()
+    gtk.gdk.threads_enter()
     camera.set_window_id(self._widgetTree.get_widget("Photo").window.xid)
 #    camera.click("/tmp/mnotes.jpg")
 #    camera.display()
